@@ -300,7 +300,7 @@ sub readMessages(@)
         my @body;
 
         while(<$file>)
-        {   last if m/^From /;
+        {   last if m/^From\s.*(19\d\d|20\d\d)$/;
             push @body, $_;
             $end = $file->tell;
         }
@@ -793,7 +793,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 1.004
+This code is beta, version 1.100
 
 =cut
 
